=======
History
=======

********************
1.1.0 ( 2026-03-23 )
********************

* se cambio el comportamiento para que AllowUsers se parse como lista y si se 
  serializa una cadena la maneja como lista de un elemento

********************
1.0.0 ( 2026-03-22 )
********************

* se agrega clase de file para las configuracion de sshd
* se agrega clase de file para las llaves authorizadas de los usuarios

********************
0.0.1 ( 2026-03-22 )
********************

* First release on PyPI.
